function [] = infer_young()
    % Load Data
    clear
    load human_to_reduced_data/data_spatial_2.mat areas counts hascenter hasfans...
        hasclimatefans hasembed haslakes ids;
    
    % Set Constants
    max_time = 3.54;
    num_units = length(areas);
    t = (0:0.05:max_time);
    p = (0:0.01:1); 
    exp_likelihood = zeros(length(p), length(t));
    [t_, p_] = meshgrid(t,p);
    
    for i = 1:length(p)
        for j = 1:length(t)
            log_likelihood_sum = 0;
            for k = 1:num_units
                %young run has max 3.54
                [posterior, tc] = age_posterior(counts(k),areas(k),3.54);
                log_likelihood_sum = log_likelihood_sum +...
                    log10(sum(posterior.*step_likely(t(j),p(i),tc,hasfans(k))));

            end
            exp_likelihood(i,j) = log_likelihood_sum;
        end
        disp(i)
    end

    exp_likelihood(exp_likelihood == 0) = NaN;
    save stepdata_young_spatial_2 t_ p_ exp_likelihood
end

function likelihood = step_likely(t_spike, p_max, x,hasfan)
    likelihood = 0.001 + (p_max-0.001)*(x >= t_spike);
    if hasfan == 0
       likelihood = 1-likelihood; 
    end
end

function likelihood = slope_likely(t1,t2,p_max,x,hasfan)
    likelihood = interp1([-0.1,t1,t2,100], [0.001,0.001,p_max,p_max],x);
    if hasfan == 0
       likelihood = 1-likelihood; 
    end
end

function [posterior, tc] = age_posterior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end